Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1328)

Unified Diff: chrome/browser/chromeos/power_library.h

Issue 341044: Move chromeos code to namespace chromeos. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/power_library.h
===================================================================
--- chrome/browser/chromeos/power_library.h (revision 30488)
+++ chrome/browser/chromeos/power_library.h (working copy)
@@ -2,26 +2,28 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_CROS_POWER_LIBRARY_H_
-#define CHROME_BROWSER_CHROMEOS_CROS_POWER_LIBRARY_H_
+#ifndef CHROME_BROWSER_CHROMEOS_POWER_LIBRARY_H_
+#define CHROME_BROWSER_CHROMEOS_POWER_LIBRARY_H_
#include "base/observer_list.h"
#include "base/singleton.h"
#include "base/time.h"
#include "third_party/cros/chromeos_power.h"
+namespace chromeos {
+
// This class handles the interaction with the ChromeOS power library APIs.
// Classes can add themselves as observers. Users can get an instance of this
-// library class like this: CrosPowerLibrary::Get()
-class CrosPowerLibrary {
+// library class like this: PowerLibrary::Get()
+class PowerLibrary {
public:
class Observer {
public:
- virtual void PowerChanged(CrosPowerLibrary* obj) = 0;
+ virtual void PowerChanged(PowerLibrary* obj) = 0;
};
- // This gets the singleton CrosPowerLibrary
- static CrosPowerLibrary* Get();
+ // This gets the singleton PowerLibrary
+ static PowerLibrary* Get();
// Returns true if the ChromeOS library was loaded.
static bool loaded();
@@ -48,10 +50,10 @@
base::TimeDelta battery_time_to_full() const;
private:
- friend struct DefaultSingletonTraits<CrosPowerLibrary>;
+ friend struct DefaultSingletonTraits<PowerLibrary>;
- CrosPowerLibrary();
- ~CrosPowerLibrary();
+ PowerLibrary();
+ ~PowerLibrary();
// This method is called when there's a change in power status.
// This method is called on a background thread.
@@ -74,7 +76,9 @@
// The latest power status.
chromeos::PowerStatus status_;
- DISALLOW_COPY_AND_ASSIGN(CrosPowerLibrary);
+ DISALLOW_COPY_AND_ASSIGN(PowerLibrary);
};
-#endif // CHROME_BROWSER_CHROMEOS_CROS_POWER_LIBRARY_H_
+} // namespace chromeos
+
+#endif // CHROME_BROWSER_CHROMEOS_POWER_LIBRARY_H_
Property changes on: chrome/browser/chromeos/power_library.h
___________________________________________________________________
Added: svn:eol-style
+ LF

Powered by Google App Engine
This is Rietveld 408576698